Installation
============

A stable *pip* installation release for scDREAMER package will be made available shortly. For now, we recommend users to directly clone our stable *main* branch and set *scDREAMER* as the working directory. 
Creating conda environment using ./ENVIRONMENTS/scDREAMER.yml will install all the dependent packages and libraries. 
scDREAMER can be set up as follows::

   git clone https://github.com/Zafar-Lab/scDREAMER.git
   cd scDREAMER/Environments
   conda env create -f scDREAMER.yml
   conda activate scdreamer